package betterquesting.api2.client.gui.panels.bars;

import betterquesting.api2.client.gui.misc.IGuiRect;
import betterquesting.api2.client.gui.resources.textures.IGuiTexture;
import betterquesting.api2.client.gui.themes.presets.PresetTexture;
import java.util.List;
import net.minecraft.util.MathHelper;
import org.lwjgl.input.Mouse;
import org.lwjgl.opengl.GL11;

/* loaded from: betterquesting_api2_client_gui_panels_bars.jar:betterquesting/api2/client/gui/panels/bars/PanelVScrollBar.class */
public class PanelVScrollBar implements IScrollBar {
    private final IGuiRect transform;
    private IGuiTexture texBack;
    private boolean enabled = true;
    private boolean active = true;
    private IGuiTexture[] texHandleState = new IGuiTexture[3];
    private float scroll = 0.0f;
    private float speed = 0.1f;
    private int hSize = 16;
    private int inset = 0;
    private boolean isDragging = false;

    public PanelVScrollBar(IGuiRect rect) {
        this.transform = rect;
        setBarTexture(PresetTexture.SCROLL_V_BG.getTexture(), PresetTexture.SCROLL_V_0.getTexture(), PresetTexture.SCROLL_V_1.getTexture(), PresetTexture.SCROLL_V_2.getTexture());
    }

    @Override // betterquesting.api2.client.gui.panels.bars.IScrollBar
    public PanelVScrollBar setHandleSize(int size, int inset) {
        this.hSize = size;
        this.inset = inset;
        return this;
    }

    @Override // betterquesting.api2.client.gui.panels.bars.IScrollBar
    public PanelVScrollBar setBarTexture(IGuiTexture back, IGuiTexture handleDisabled, IGuiTexture handleIdle, IGuiTexture handleHover) {
        this.texBack = back;
        this.texHandleState[0] = handleDisabled;
        this.texHandleState[1] = handleIdle;
        this.texHandleState[2] = handleHover;
        return this;
    }

    @Override // betterquesting.api2.client.gui.panels.bars.IScrollBar
    public PanelVScrollBar setScrollSpeed(float f) {
        this.speed = f;
        return this;
    }

    public void initPanel() {
    }

    public void setEnabled(boolean state) {
        this.enabled = state;
    }

    public boolean isEnabled() {
        return this.enabled;
    }

    @Override // betterquesting.api2.client.gui.panels.bars.IScrollBar
    public void setActive(boolean state) {
        this.active = state;
    }

    @Override // betterquesting.api2.client.gui.panels.bars.IScrollBar
    public boolean isActive() {
        return this.active;
    }

    public IGuiRect getTransform() {
        return this.transform;
    }

    public void drawPanel(int mx, int my, float partialTick) {
        IGuiRect bounds = getTransform();
        if (this.active && this.isDragging && (Mouse.isButtonDown(0) || Mouse.isButtonDown(2))) {
            float cy = (my - (bounds.getY() + (this.hSize / 2))) / (bounds.getHeight() - this.hSize);
            writeValue(Float.valueOf(cy));
        } else if (this.isDragging) {
            this.isDragging = false;
        }
        GL11.glPushMatrix();
        GL11.glColor4f(1.0f, 1.0f, 1.0f, 1.0f);
        if (this.texBack != null) {
            this.texBack.drawTexture(bounds.getX(), bounds.getY(), bounds.getWidth(), bounds.getHeight(), 0.0f, partialTick);
        }
        int sy = MathHelper.func_76141_d(((bounds.getHeight() - this.hSize) - (this.inset * 2)) * this.scroll);
        int state = !this.active ? 0 : (this.isDragging || bounds.contains(mx, my)) ? 2 : 1;
        IGuiTexture tex = this.texHandleState[state];
        if (tex != null) {
            tex.drawTexture(bounds.getX() + this.inset, bounds.getY() + sy + this.inset, bounds.getWidth() - (this.inset * 2), this.hSize, 0.0f, partialTick);
        }
        GL11.glPopMatrix();
    }

    public boolean onMouseClick(int mx, int my, int click) {
        IGuiRect bounds = getTransform();
        if (!this.active || !bounds.contains(mx, my)) {
            return false;
        }
        if (click == 0 || click == 2) {
            this.isDragging = true;
            return true;
        }
        return false;
    }

    public boolean onMouseRelease(int mx, int my, int click) {
        return false;
    }

    public boolean onMouseScroll(int mx, int my, int sdx) {
        IGuiRect bounds = getTransform();
        if (!this.active || sdx == 0 || !bounds.contains(mx, my)) {
            return false;
        }
        float dy = sdx * this.speed;
        if (dy < 0.0f && this.scroll <= 0.0f) {
            return false;
        }
        if (dy > 0.0f && this.scroll >= 1.0f) {
            return false;
        }
        writeValue(Float.valueOf(dy + this.scroll));
        return true;
    }

    public boolean onKeyTyped(char c, int keycode) {
        return false;
    }

    public List<String> getTooltip(int mx, int my) {
        return null;
    }

    /* renamed from: readValue, reason: merged with bridge method [inline-methods] */
    public Float m3readValue() {
        return Float.valueOf(this.scroll);
    }

    public void writeValue(Float value) {
        this.scroll = MathHelper.func_76131_a(value.floatValue(), 0.0f, 1.0f);
    }

    /* renamed from: readValueRaw, reason: merged with bridge method [inline-methods] */
    public Float m2readValueRaw() {
        return m3readValue();
    }

    public void writeValueRaw(Float value) {
        this.scroll = value.floatValue();
    }
}
